==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=eo
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Restarigi',
	'boxstr_close' => 'Fermi',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Sekva',
	'boxstr_previous' => 'Antaŭa',
	'boxstr_slideshowStart' => 'Lumbildo',
	'boxstr_slideshowStop' => 'Haltigi',
	'boxstr_zoom' => 'Zomo',

	// E
	'explication_selecteur' => 'Indiki la celon de la elementoj, kiuj ekigos la skatolon (CSS- aŭ jQuery-esprimoj).',
	'explication_selecteur_galerie' => 'Indiki la celon de la elementoj grupigendaj galerie (CSS- aŭ jQuery-esprimoj).',
	'explication_splash_url' => 'Indiki la retadreson (URL) de la datummedio, kiu aperos aŭtomate okaze de la unua vizito ĉe la publika retejo.',
	'explication_traiter_toutes_images' => 'Uzi skatolon ĉe ĉiujn bildojn ?',

	// L
	'label_active' => 'Aktivigi la Plurmedian skatolon ĉe la publika retejo',
	'label_apparence' => 'Aspekto',
	'label_aucun_style' => 'Uzi nenian etoson defaŭlte',
	'label_choix_transition_elastic' => 'Elasta',
	'label_choix_transition_fade' => 'Fado-malfado',
	'label_choix_transition_none' => 'Sen transpas-efekto',
	'label_maxheight' => 'Maksimuma alto (% aŭ px)',
	'label_maxwidth' => 'Maksimuma larĝo (% aŭ px)',
	'label_minheight' => 'Minimuma alto (% aŭ px)',
	'label_minwidth' => 'Minimuma larĝo (% aŭ px)',
	'label_opacite' => 'Travidebleco de la fono',
	'label_selecteur_commun' => 'Ĝenerale',
	'label_selecteur_galerie' => 'Galerie',
	'label_skin' => 'Vida etoso',
	'label_slideshow_speed' => 'Montrodaŭro de la lumbildaj fotoj (ms)',
	'label_speed' => 'Transpas-rapido (ms)',
	'label_splash' => 'Unuavizita skatolo',
	'label_splash_height' => 'Alto (% aŭ px)',
	'label_splash_url' => 'Retadreso (URL) afiŝonta',
	'label_splash_width' => 'Larĝo (% aŭ px)',
	'label_traiter_toutes_images' => 'Bildoj',
	'label_transition' => 'Transpaso inter du vidoj',

	// T
	'titre_menu_box' => 'Plurmedia skatolo',
	'titre_page_configurer_box' => 'Agordoj de la Plurmedia skatolo'
);

==> spip_4.4.8+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_reinitialiser' => 'Restarigi',
	'boxstr_close' => 'Fermi',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Sekva',
	'boxstr_previous' => 'Antaŭa',
	'boxstr_slideshowStart' => 'Lumbildo',
	'boxstr_slideshowStop' => 'Haltigi',
	'boxstr_zoom' => 'Zomo',

	// E
	'explication_selecteur' => 'Indiki la celon de la elementoj, kiuj ekigos la skatolon (CSS- aŭ jQuery-esprimoj).',
	'explication_selecteur_galerie' => 'Indiki la celon de la elementoj grupigendaj galerie (CSS- aŭ jQuery-esprimoj).',
	'explication_splash_url' => 'Indiki la retadreson (URL) de la datummedio, kiu aperos aŭtomate okaze de la unua vizito ĉe la publika retejo.',
	'explication_traiter_toutes_images' => 'Uzi skatolon ĉe ĉiujn bildojn ?',

	// L
	'label_active' => 'Aktivigi la Plurmedian skatolon ĉe la publika retejo',
	'label_apparence' => 'Aspekto',
	'label_aucun_style' => 'Uzi nenian etoson defaŭlte',
	'label_choix_transition_elastic' => 'Elasta',
	'label_choix_transition_fade' => 'Fado-malfado',
	'label_choix_transition_none' => 'Sen transpas-efekto',
	'label_maxheight' => 'Maksimuma alto (% aŭ px)',
	'label_maxwidth' => 'Maksimuma larĝo (% aŭ px)',
	'label_minheight' => 'Minimuma alto (% aŭ px)',
	'label_minwidth' => 'Minimuma larĝo (% aŭ px)',
	'label_opacite' => 'Travidebleco de la fono',
	'label_selecteur_commun' => 'Ĝenerale',
	'label_selecteur_galerie' => 'Galerie',
	'label_skin' => 'Vida etoso',
	'label_slideshow_speed' => 'Montrodaŭro de la lumbildaj fotoj (ms)',
	'label_speed' => 'Transpas-rapido (ms)',
	'label_splash' => 'Unuavizita skatolo',
	'label_splash_height' => 'Alto (% aŭ px)',
	'label_splash_url' => 'Retadreso (URL) afiŝonta',
	'label_splash_width' => 'Larĝo (% aŭ px)',
	'label_traiter_toutes_images' => 'Bildoj',
	'label_transition' => 'Transpaso inter du vidoj',

	// T
	'titre_menu_box' => 'Plurmedia skatolo',
	'titre_page_configurer_box' => 'Agordoj de la Plurmedia skatolo',
];
